@@ -22,7 +22,7 @@
 #include	<unistd.h>
 #endif
 
-static const char rcsid[]="$Id: maildirfilter.c,v 1.11 2001/08/18 21:51:43 mrsam Exp $";
+static const char rcsid[]="$Id: maildirfilter.c,v 1.15 2002/06/18 03:21:57 mrsam Exp $";
 
 struct maildirfilterrule *mf_appendrule(struct maildirfilter *r,
 					const char *name,
@@ -424,7 +424,7 @@ char quotabuf[QUOTABUFSIZE];
 		if (*fromaddr != '"' && *fromaddr != '\'' && *fromaddr != '\\')
 			putc(*fromaddr, f);
 	}
-	fprintf(f, "\'\n\n");
+	fprintf(f, "\'\nimport SENDER\nif ($SENDER eq \"\")\n{\n SENDER=$FROM\n}\n\n");
 
 	for (p=r->first; p; p=p->next)
 	{
@@ -519,7 +519,7 @@ char quotabuf[QUOTABUFSIZE];
 
 		if (*tofolder == '!')
 		{
-			fprintf(f, "    %s \"| $SENDMAIL -f '$FROM' %s\"\n",
+			fprintf(f, "    %s \"| $SENDMAIL -f \" '\"$SENDER\"' \" %s\"\n",
 				p->flags & MFR_CONTINUE ? "cc":"to",
 					tofolder+1);
 		}
@@ -555,7 +555,7 @@ char quotabuf[QUOTABUFSIZE];
 						" -d \"%s/autoresponses/"
 						"%s.dat\" -D %u",
 					maildirpath, ai.name, ai.days);
-				fprintf(f, " $SENDMAIL -f \"\"`\n");
+				fprintf(f, " $SENDMAIL -t -f \"\"`\n");
 				mf_autoresp_info_free(&ai);
 			}
 		}
