@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.
+** Copyright 1998 - 2002 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -9,12 +9,19 @@
 #include	"numlib.h"
 #include	<string.h>
 
-static const char rcsid[]="$Id: strofft.c,v 1.3 2000/05/27 04:59:26 mrsam Exp $";
+static const char rcsid[]="$Id: strofft.c,v 1.4 2002/06/10 00:33:55 mrsam Exp $";
 
 char *str_off_t(off_t t, char *arg)
 {
-char	buf[NUMBUFSIZE];
-char	*p=buf+sizeof(buf)-1;
+	char	buf[NUMBUFSIZE];
+	char	*p=buf+sizeof(buf)-1;
+	int	isneg=0;
+
+	if (t < 0)
+	{
+		t= -t;
+		isneg=1;
+	}
 
 	*p=0;
 	do
@@ -22,5 +29,9 @@ char	*p=buf+sizeof(buf)-1;
 		*--p= '0' + (t % 10);
 		t=t / 10;
 	} while(t);
+
+	if (isneg)
+		*--p='-';
+
 	return (strcpy(arg, p));
 }
