@@ -1,10 +1,10 @@
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2002 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 /*
-** $Id: rfc2045.c,v 1.28 2001/11/26 04:03:51 mrsam Exp $
+** $Id: rfc2045.c,v 1.30 2002/03/19 01:29:18 mrsam Exp $
 */
 #if    HAVE_CONFIG_H
 #include       "config.h"
@@ -407,7 +407,11 @@ int	bit8=0;
 	}
 
 	for (k=0; k<cnt; k++)
+	{
+		if (c[k] == 0)
+			c[k]=' ';
 		if (c[k] & 0x80)	bit8=1;
+	}
 
 	if (n && c[n-1] == '\r')	/* Strip trailing \r */
 		--n;
@@ -441,7 +445,7 @@ int	bit8=0;
 
 		if (p->lastpart->workclosed)
 		{
-			update_counts(p, p->endpos+cnt, p->endpos+cnt, 1);
+			update_counts(p, p->endpos+cnt, p->endpos+n, 1);
 			return;
 		}
 		/* Leftover trash -- workclosed is set when the final
